@@ -201,6 +201,7 @@ bool LibPython::loadSymbols(bool python3, std::string* pError)
   LOAD_PYTHON_SYMBOL(PyDict_Keys)
   LOAD_PYTHON_SYMBOL(PyDict_Values)
   LOAD_PYTHON_SYMBOL(PyDict_Size)
+  LOAD_PYTHON_SYMBOL(PyDict_Copy)
   LOAD_PYTHON_SYMBOL(PyFloat_AsDouble)
   LOAD_PYTHON_SYMBOL(PyFloat_FromDouble)
   LOAD_PYTHON_SYMBOL(PyFunction_Type)
@@ -214,6 +215,7 @@ bool LibPython::loadSymbols(bool python3, std::string* pError)
   LOAD_PYTHON_SYMBOL(PyObject_Call)
   LOAD_PYTHON_SYMBOL(PyObject_CallFunctionObjArgs)
   LOAD_PYTHON_SYMBOL(PyType_IsSubtype)
+  LOAD_PYTHON_SYMBOL(PySys_WriteStderr)
 
   if (python3) {
     LOAD_PYTHON_SYMBOL(PyModule_Create2)
